@@ -9,19 +9,21 @@ class FitnessEvaluator(AbstractFitnessEvaluator):
     def __init__(
         self,
         evaluator: DesignPointEvaluator,
-        approx: bool = False,
-        control: str = "Distance",
-        estim: str = "HoeffdingAdaptiveTree",
+        disable: bool = False,
+        controller: str = "Distance",
+        estimator: str = "HoeffdingAdaptiveTree",
+        controller_mab_weight: bool = False,
         **kwargs
     ):
 
         self.__evaluator: DesignPointEvaluator = evaluator
         self.fitness = approximate(
-            disabled=approx,
+            disabled=disable,
             outputs=len(self.__evaluator.get_metrics()),
-            estimator=estim,
-            controller=control,
+            estimator=estimator,
+            controller=controller,
             controller_debug=True,
+            controller_mab_weight=controller_mab_weight,
             **kwargs
         )(self.fitness)
 
